@@ -113,9 +113,9 @@ bool testStderr(const QByteArray &stderrData, TestInterface::ReadStderrFlag flag
     return output.indexOf(scriptExceptionError) == -1;
 }
 
-QByteArray getClipboard(const QString &mime = QString("text/plain"))
+QByteArray getClipboard(const QString &mime = QString("text/plain"), ClipboardMode mode = ClipboardMode::Clipboard)
 {
-    const QMimeData *data = clipboardData();
+    const QMimeData *data = clipboardData(mode);
     return (data != nullptr) ? data->data(mime) : QByteArray();
 }
 
@@ -373,21 +373,24 @@ public:
         return readServerErrors(ReadErrorsWithoutScriptException);
     }
 
-    QByteArray setClipboard(const QByteArray &bytes, const QString &mime) override
+    QByteArray setClipboard(const QByteArray &bytes, const QString &mime, ClipboardMode mode) override
     {
-        if ( getClipboard(mime) == bytes )
+        if ( getClipboard(mime, mode) == bytes )
             return QByteArray();
 
         waitFor(waitMsSetClipboard);
 
         auto mimeData = new QMimeData();
         mimeData->setData(mime, bytes);
-        QGuiApplication::clipboard()->setMimeData(mimeData);
+        const auto qmode = mode == ClipboardMode::Clipboard ? QClipboard::Clipboard : QClipboard::Selection;
+        QGuiApplication::clipboard()->setMimeData(mimeData, qmode);
 
         waitFor(waitMsSetClipboard);
 
         waitUntilClipboardSet(bytes, mime);
-        RETURN_ON_ERROR( testClipboard(bytes, mime), "Failed to set clipboard" );
+        RETURN_ON_ERROR(
+            testClipboard(bytes, mime),
+            "Failed to set " + QByteArray(mode == ClipboardMode::Clipboard ? "clipboard" : "selection") );
 
         return QByteArray();
     }
@@ -481,7 +484,10 @@ public:
         verifyConfiguration();
 
         // Clear clipboard.
-        RETURN_ON_ERROR( setClipboard(QByteArray(), mimeText), "Failed to reset clipboard" );
+        RETURN_ON_ERROR( setClipboard(QByteArray(), mimeText, ClipboardMode::Clipboard), "Failed to reset clipboard" );
+#ifdef HAS_MOUSE_SELECTIONS
+        RETURN_ON_ERROR( setClipboard(QByteArray(), mimeText, ClipboardMode::Selection), "Failed to reset selection" );
+#endif
 
         RETURN_ON_ERROR( startServer(), "Failed to start server" );
 
@@ -2531,7 +2537,7 @@ void Tests::automaticCommandIgnore()
     const auto script = R"(
         setCommands([
             { automatic: true, cmd: 'copyq ignore; copyq add OK' },
-            { automatic: true, cmd: 'copyq add "SHOULDN NOT BE EXECUTED"' }
+            { automatic: true, cmd: 'copyq add "SHOULD NOT BE EXECUTED"' }
         ])
         )";
     RUN(script, "");
@@ -2550,7 +2556,7 @@ void Tests::automaticCommandRemove()
     const auto script = R"(
         setCommands([
             { automatic: true, remove: true, cmd: 'copyq add OK' },
-            { automatic: true, cmd: 'copyq add "SHOULDN NOT BE EXECUTED"' }
+            { automatic: true, cmd: 'copyq add "SHOULD NOT BE EXECUTED"' }
         ])
         )";
     RUN(script, "");
@@ -2659,6 +2665,37 @@ void Tests::automaticCommandCopyToTab()
     RUN("tab" << tab1 << "read" << "0", "TEST");
 }
 
+void Tests::automaticCommandStoreSpecialFormat()
+{
+    const auto script = R"(
+        setCommands([
+            { automatic: true, name: 'CMD1', input: 'test-format' }
+        ])
+        )";
+    RUN(script, "");
+
+    TEST( m_test->setClipboard("DATA", "test-format") );
+    WAIT_ON_OUTPUT("separator" << "," << "read" << "test-format" << "0" << "1", "DATA,");
+}
+
+void Tests::automaticCommandIgnoreSpecialFormat()
+{
+    const auto script = R"(
+        setCommands([
+            { automatic: true, name: 'CMD1', cmd: 'copyq add CMD1', input: 'test-format', remove: true },
+            { automatic: true, name: 'CMD2', cmd: 'copyq add CMD2' },
+            { automatic: true, name: 'CMD3', cmd: 'copyq add CMD3', input: 'test-format' }
+        ])
+        )";
+    RUN(script, "");
+
+    TEST( m_test->setClipboard("SHOULD BE IGNORED", "test-format") );
+    WAIT_ON_OUTPUT("separator" << "," << "read" << "0" << "1", "CMD1,");
+
+    TEST( m_test->setClipboard("SHOULD NOT BE IGNORED") );
+    WAIT_ON_OUTPUT("separator" << "," << "read" << "0" << "1" << "2" << "3", "SHOULD NOT BE IGNORED,CMD2,CMD1,");
+}
+
 void Tests::scriptCommandLoaded()
 {
     const auto script = R"(
